@@ -1,6 +1,8 @@
 
-""" ``routing`` package.
 """
+"""
+
+__version__ = '0.1.145'
 
 # flake8: noqa
 
